@@ -2197,26 +2197,28 @@ arrays (see above in this file)
 
  It is used to allocate storage and later populate these values
 */
-SparseFM::SparseFM() {}
-SparseFM::SparseFM( struct  fm_env_sparse* penv): 
-	n(penv->n),
-    m_singletons( penv->m_singletons, penv->m_singletons + penv->n),
-    m_pairs( penv->m_pairs, penv->m_pairs + penv->n),
-    m_tuples( penv->m_tuples, penv->m_tuples + penv->n),
-    m_pair_index( penv->m_pair_index, penv->m_pair_index + penv->n),
-    m_tuple_start( penv->m_tuple_start, penv->m_tuple_start + penv->n),
-    m_tuple_content( penv->m_tuple_content, penv->m_tuple_content + penv->n) {}
+
+// SparseFM::SparseFM() {}
+// SparseFM::SparseFM( struct  fm_env_sparse* penv): 
+// 	   n(penv->n),
+//     m_singletons( penv->m_singletons, penv->m_singletons + penv->n),
+//     m_pairs( penv->m_pairs, penv->m_pairs + penv->n),
+//     m_tuples( penv->m_tuples, penv->m_tuples + penv->n),
+//     m_pair_index( penv->m_pair_index, penv->m_pair_index + penv->n),
+//     m_tuple_start( penv->m_tuple_start, penv->m_tuple_start + penv->n),
+//     m_tuple_content( penv->m_tuple_content, penv->m_tuple_content + penv->n) {}
 
 LIBEXP void py_prepare_fm_sparse( int n, int tupsize, int* tuples, struct fm_env_sparse* env)
 {
-	SparseFM* psFM = new SparseFM( env); 
-	Prepare_FM_sparse0(n, tupsize, tuples, psFM);
-	env->m_sparce_fm = psFM;
-	// Prepare_FM_sparse0(n, tupsize, tuples, (SparseFM*)env);
+	// SparseFM* psFM = new SparseFM( env); 
+	// Prepare_FM_sparse0(n, tupsize, tuples, psFM);
+	// env->m_sparce_fm = psFM;
+
+	Prepare_FM_sparse0(n, tupsize, tuples, (SparseFM*)env);
 }
 LIBEXP void py_free_fm_sparse(struct fm_env_sparse* env) {
 	Free_FM_sparse((SparseFM*)env);
-	delete( (SparseFM*)env->m_sparce_fm);
+	// delete( (SparseFM*)env->m_sparce_fm);
 }
 
 /*  Returns the cardinality of the tuple numbered i in the list of tuples */
